/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.configuration.extender.internal;

import com.liferay.petra.function.UnsafeSupplier;
import com.liferay.petra.string.StringBundler;

import java.io.IOException;

import java.util.Dictionary;

/**
 * @author Carlos Sierra Andrés
 */
public class NamedConfigurationContent {

	public NamedConfigurationContent(
		String factoryPid, String pid,
		UnsafeSupplier<Dictionary<?, ?>, IOException> propertySupplier) {

		_factoryPid = factoryPid;
		_pid = pid;
		_propertySupplier = propertySupplier;
	}

	public String getFactoryPid() {
		return _factoryPid;
	}

	public String getPid() {
		return _pid;
	}

	@SuppressWarnings("unchecked")
	public Dictionary<String, Object> getProperties() throws IOException {
		Dictionary<?, ?> properties = _propertySupplier.get();

		return (Dictionary<String, Object>)properties;
	}

	@Override
	public String toString() {
		return StringBundler.concat(
			"{factoryPid=", _factoryPid, ", pid=", _pid, "}");
	}

	private final String _factoryPid;
	private final String _pid;
	private final UnsafeSupplier<Dictionary<?, ?>, IOException>
		_propertySupplier;

}